@@ -136,18 +136,18 @@ OC.L10N.register(
     "Share calendar" : "Koplietot kalendāru",
     "Unshare from me" : "Atcelt koplietošanu no manis",
     "Save" : "Saglabāt",
-    "Import calendars" : "Importēt kalendārus",
+    "Import calendars" : "Ievietot kalendārus",
     "Please select a calendar to import into …" : "Lūgums atlasīt kalendāru, kurā ievietot ...",
     "Filename" : "Datnes nosaukums",
     "Calendar to import into" : "Kalendārs, kurā ievietot",
     "Cancel" : "Atcelt",
     "Select the default location for attachments" : "Atlasīt pielikumu noklusējuma atrašanās vietu",
     "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
-    "Attachments folder successfully saved." : "Pielikumu mape veiksmīgi saglabāta.",
+    "Attachments folder successfully saved." : "Pielikumu mape saglabāta sekmīgi.",
     "Error on saving attachments folder." : "Kļūda saglabājot pielikumu mapi.",
     "Default attachments location" : "Pielikumu noklusējuma atrašanās vietas",
     "No valid files found, aborting import" : "Nav atrastas derīgas datnes, ievietošana tiek pārtraukta.",
-    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Veiksmīgi importēti %n notikumi","Veiksmīgi importēts %n notikums","Veiksmīgi importēti %n notikumi"],
+    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Sekmīgi ievietoti %n notikumi","Sekmīgi ievietots %n notikums","Sekmīgi ievietoti %n notikumi"],
     "Import partially failed. Imported {accepted} out of {total}." : "Ievietošana daļēji neizdevās. Ievietoti {accepted} no {total}.",
     "Automatic" : "Automātisks",
     "Automatic ({detected})" : "Automātiska ({detected})",
@@ -183,7 +183,7 @@ OC.L10N.register(
     "Show weekends" : "Rādīt nedēļas nogales",
     "Show week numbers" : "Rādīt nedēļu numurus",
     "Default reminder" : "Noklusējuma atgādinājums",
-    "Copy primary CalDAV address" : "Kopēt primāro CalDAV adresi",
+    "Copy primary CalDAV address" : "Ievietot starpliktuvē galveno CalDAV adresi",
     "Copy iOS/macOS CalDAV address" : "Kopēt IOS/macOS CalDAV adresi",
     "Personal availability settings" : "Personiskās pieejamības iestatījumi",
     "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
@@ -224,7 +224,7 @@ OC.L10N.register(
     "Your name" : "Tavs vārds",
     "Your email address" : "Jūsu e-pasta adrese",
     "Please share anything that will help prepare for our meeting" : "Lūdzu, dalieties ar visu, kas palīdzēs sagatavoties mūsu sanāksmei",
-    "Could not book the appointment. Please try again later or contact the organizer." : "Neizdevās rezervēt tikšanos. Lūdzu, mēģiniet vēlreiz vēlāk vai sazinieties ar organizatoru.",
+    "Could not book the appointment. Please try again later or contact the organizer." : "Neizdevās pieteikt tikšanos. Lūgums vēlāk mēģināt vēlreiz vai sazināties ar rīkotāju.",
     "Successfully added Talk conversation link to location." : "Talk sarunas saite sekmīgi pievienota atrašanās vietai.",
     "Successfully added Talk conversation link to description." : "Talk sarunas saite sekmīgi pievienota aprakstam.",
     "Failed to apply Talk room." : "Neizdevās pielietot Talk istabu.",
@@ -279,9 +279,9 @@ OC.L10N.register(
     "Busy" : "Aizņemts",
     "Unknown" : "Nezināms",
     "Find a time" : "Atrast laiku",
-    "The invitation has been accepted successfully." : "Uzaicinājums ir veiksmīgi apstiprināts.",
+    "The invitation has been accepted successfully." : "Uzaicinājums tika sekmīgi apstiprināts.",
     "Failed to accept the invitation." : "Neizdevās apstiprināt uzaicinājumu.",
-    "The invitation has been declined successfully." : "Uzaicinājums ir veiksmīgi noraidīts.",
+    "The invitation has been declined successfully." : "Uzaicinājums tika sekmīgi noraidīts.",
     "Failed to decline the invitation." : "Neizdevās atteikt uzaicinājumu.",
     "Your participation has been marked as tentative." : "Jūsu piedalīšanās ir atzīmēta kā nenoteikta.",
     "Failed to set the participation status to tentative." : "Neizdevās iestatīt dalības stāvokli kā nenoteiktu.",
@@ -301,7 +301,7 @@ OC.L10N.register(
     "Search for emails, users, contacts, contact groups or teams" : "Meklēt e-pasta adreses, lietotājus, kontaktpersonas, saziņas kopas vai komandas",
     "Remove color" : "Noņemt krāsu",
     "Event title" : "Notikuma nosaukums",
-    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nevar modificēt visas dienas iestatījumu notikumiem, kas ir daļa no atkārtojumu kopas.",
+    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nevar izmainīt visas dienas iestatījumu notikumiem, kas ir daļa no atkārtojumu kopas.",
     "From" : "No",
     "To" : "Līdz",
     "Repeat" : "Atkārtot",
@@ -364,9 +364,9 @@ OC.L10N.register(
     "Time:" : "Laiks:",
     "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Paldies! Rezervācija no {startDate} līdz {endDate} tika apstiprināta.",
     "Book another appointment:" : "Rezervēt vēl vienu plānotu tikšanos",
-    "Book an appointment with {name}" : "Rezervējiet plānotu tikšanos ar {name}",
+    "Book an appointment with {name}" : "Pieteikt tikšanos ar {name}",
     "Personal" : "Personīgs",
-    "Edit event" : "Rediģēt notikumu",
+    "Edit event" : "Labot notikumu",
     "Event does not exist" : "Notikums nepastāv",
     "Duplicate" : "Pavairot",
     "Delete this occurrence" : "Izdzēst šo notikumu",
@@ -453,7 +453,7 @@ OC.L10N.register(
     "Attachment {fileName} already exists!" : "Pielikums {fileName} jau pastāv.",
     "An error occurred during getting file information" : "Kļūda datnes informācijas iegūšanas laikā",
     "An error occurred, unable to delete the calendar." : "Atgadījās kļūda, neizdevās izdzēst kalendāru.",
-    "Imported {filename}" : "Importēts {filename}",
+    "Imported {filename}" : "Ievietota {filename}",
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
     "User not found" : "Lietotājs nav atrasts",
